package de.tu_darmstadt.tk.SmartHomeNetworkSim.core;

import de.tu_darmstadt.tk.SmartHomeNetworkSim.control.Controller;

/**
 * Interface for programs/algorithms/manipulations/optimizations which could run during each
 * simulation step. The Main Controller which is an argument is quite powerful and
 * allows full access to the whole model, simulation, parts of the GUI and
 * should be used wisely.<br>
 * The runAlgorithm method will be called at the end of each simulation cycle,
 * if imported and added to the simulation.
 *
 * @author Andreas T. Meyer-Berg
 */
public interface NetworkManipulationAlgorithm {

	/**
	 * 
	 * @param controller
	 *            Main controller of the framework, access to the network model,
	 *            settings, simulation etc.
	 * @param currentTimeStep
	 *            current time in the simulation
	 */
	public void runAlgorithm(Controller controller, long currentTimeStep);
}
